StreamToObservableAdapter<T> class

Adapter that wraps a Stream T and exposes IObservableListenable T

Implemented types

Constructors

StreamToObservableAdapter(Stream<T> _stream)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
If all listeners properly cancel their subscriptions no need to call dispose in StreamToObservableAdapter,
override
listen(void listener(T)) ObservableSubscription<T>
Custom stream-like listen with custom subscription More convenient than addListener API, but works same as AddListener/RemoveListener for sync version, so expect same result For async version works just like stream.listen
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited