builder property
Builds the UI based on the current value of the observable.
Implementation
final Widget Function(BuildContext context, T value) builder;
Builds the UI based on the current value of the observable.
final Widget Function(BuildContext context, T value) builder;