builder property
Builder function that uses both observable values to build the widget.
Implementation
final Widget Function(BuildContext context, A o, B o2) builder;
Builder function that uses both observable values to build the widget.
final Widget Function(BuildContext context, A o, B o2) builder;