builder property
Builds the widget using values from all three observables.
Implementation
final Widget Function(BuildContext context, A o, B o2, C o3) builder;
Builds the widget using values from all three observables.
final Widget Function(BuildContext context, A o, B o2, C o3) builder;