ObservableListener<T> class
A stateless widget that listens to an observable and triggers the provided listener callback whenever the value changes.
Unlike ObservableConsumer, this widget does not rebuild itself. It is meant for side effects only (e.g., showing dialogs, triggering actions).
Usage: ObservableListener( observable: counter, listener: (context, value) { if (value > 10) { ScaffoldMessenger.of(context).showSnackBar(...); } }, child: MyWidget(), );
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ObservableListener
Constructors
-
ObservableListener({Key? key, required IObservableListenable<
T> observable, required void listener(BuildContext context, T value), required Widget? child}) -
Creates an ObservableListener that listens to
observableand callslistenerwhen its value changes.const
Properties
- child → Widget?
-
The child widget to render. It does not rebuild on value change.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listener → void Function(BuildContext context, T value)
-
The callback that is triggered when the observable emits a new value.
final
-
observable
→ IObservableListenable<
T> -
The observable to listen to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited